@@ -1,3 +1,5 @@
+import datetime
+
 from httpx import Response
 
 from checkbox_api.methods.base import BaseMethod, HTTPMethod, PaginationMixin
@@ -50,3 +52,29 @@ class GetReportVisualizationText(GetReportVisualization):
     def parse_response(self, storage: SessionStorage, response: Response):
         result = super().parse_response(storage=storage, response=response)
         return result.decode()
+
+
+class GetPeriodicalReportVisualizationText(BaseMethod):
+    uri = "reports/periodical"
+
+    def __init__(self, from_date: datetime.datetime, to_date: datetime.datetime, width: int = 50):
+        super().__init__()
+        self.from_date = from_date
+        self.to_date = to_date
+        self.width = width
+
+    @property
+    def query(self):
+        query = super().query
+        query.update(
+            {
+                "from_date": self.from_date.strftime("%Y-%m-%dT%H:%M:%S%z"),
+                "to_date": self.to_date.strftime("%Y-%m-%dT%H:%M:%S%z"),
+            }
+        )
+        if self.width:
+            query["width"] = self.width
+        return query
+
+    def parse_response(self, storage: SessionStorage, response: Response):
+        return response.content.decode()
